.. currentmodule:: pyhomogenize

Functions to get the intersection of multiple netCDF files's time axis
----------------------------------------------------------------------

.. autoclass:: time_compare

   .. automethod:: __init__

   .. rubric:: Methods

   .. autosummary::

      time_compare.max_intersection

      time_compare.select_max_intersection

   .. rubric:: Attributes

   .. autosummary::

      time_compare.compare_objects

      time_compare.time_control_objects

      time_compare.times
